<p align="center">
  <img src="docs/assets/logo.svg" alt="Funtracks Logo" width="128" height="128">
</p>

# Funtracks
A data model for cell tracking with actions, undo history, persistence, and more!

[![tests](https://github.com/funkelab/funtracks/workflows/tests/badge.svg)](https://github.com/funkelab/funtracks/actions)
[![codecov](https://codecov.io/gh/funkelab/funtracks/branch/main/graph/badge.svg)](https://codecov.io/gh/funkelab/funtracks)

The full documentation can be found [here](https://funkelab.github.io/funtracks/).

----------------------------------

## Installation

`pip install funtracks`

Alternatively, you can use `uv` to install and run `funtracks` code.

## Issues

If you encounter any problems, please
[file an issue](https://github.com/funkelab/funtracks/issues)
along with a detailed description.
